==> odoo9_addon_website_seo_redirection-9.0.1.0.0.99.dev7-py2-none-any.whl: odoo_addons/website_seo_redirection/static/src/js/website_seo_redirection.tour.js <==
/* © 2016 Jairo Llopis <jairo.llopis@tecnativa.com>
 * License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl). */


odoo.define('website_seo_redirection.tour', function(require) {
    'use strict';
    
    var Tour = require('web.Tour');
    
    Tour.register({
        id: "website_seo_redirection",
        name: "Check SEO redirections functionality",
        path: "/",
        mode: "test",
        steps: [
            {
                title: "Open SEO menu",
                waitFor: "a>span:contains('SEO Sample')",
                element: "a>span:contains('SEO Sample')",
            },
            {
                title: "Go to SEO sample page in original URL",
                waitFor: "a>span:contains('Original URL')",
                element: "a>span:contains('Original URL')",
            },
            {
                title: "Page reached, back to home",
                waitFor: "#origin,#destination",
                element: "a>span:contains('Home')",
            },
            {
                title: "Open SEO menu",
                waitFor: "html[data-view-xmlid='website.homepage']",
                element: "a>span:contains('SEO Sample')",
            },
            {
                title: "Go to SEO sample page in destination URL",
                waitFor: "a>span:contains('Redirected URL')",
                element: "a>span:contains('Redirected URL')",
            },
            {
                title: "Page reached",
                waitFor: "#origin,#destination",
            },
        ],
    });
});

==> odoo9_addon_website_seo_redirection-9.0.1.1.0.99.dev9-py2-none-any.whl: odoo_addons/website_seo_redirection/static/src/js/website_seo_redirection.tour.js <==
/* © 2016 Jairo Llopis <jairo.llopis@tecnativa.com>
 * License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl). */
odoo.define('website_seo_redirection.tour', function(require) {
    'use strict';

    var Tour = require('web.Tour');

    Tour.register({
        id: "website_seo_redirection",
        name: "Check SEO redirections functionality",
        path: "/",
        mode: "test",
        steps: [
            {
                title: "Open SEO menu",
                waitFor: "a:contains('SEO Sample')",
                element: "a:contains('SEO Sample')",
            },
            {
                title: "Go to SEO sample page in original URL",
                waitFor: "a:contains('Original URL')",
                element: "a:contains('Original URL')",
            },
            {
                title: "Page reached, back to home",
                waitFor: "#origin,#destination",
                element: "a:contains('Home')",
            },
            {
                title: "Open SEO menu",
                waitFor: "meta[property='og:title'][content='Homepage']",
                element: "a:contains('SEO Sample')",
            },
            {
                title: "Go to SEO sample page in destination URL",
                waitFor: "a:contains('Redirected URL')",
                element: "a:contains('Redirected URL')",
            },
            {
                title: "Page reached",
                waitFor: "#origin,#destination",
            },
        ],
    });
});
